import { default as React } from 'react';

/**
 * Curtain UUID type.
 */
export type CurtainUuidType = string;
/**
 * The function that opens a curtain.
 */
export type OpenCurtainFunction = (content: React.ReactNode) => CurtainUuidType;
/**
 * The function that closes a curtain.
 */
export type CloseCurtainFunction = (uuid: CurtainUuidType) => void;
/**
 * The function that checks if a curtain is closed (while transitioning out) or not.
 */
export type IsCurtainClosedFunction = (uuid: CurtainUuidType) => boolean;
/**
 * Interface of curtains state.
 */
export interface CurtainsContextState {
    /**
     * Open a new curtain.
     * @param content The curtain content.
     * @return UUID of the curtain.
     */
    open: OpenCurtainFunction;
    /**
     * Close the given curtain.
     * @param uuid UUID of the curtain to close.
     */
    close: CloseCurtainFunction;
    /**
     * Check if the given curtain is closed or not.
     * @param uuid UUID of the curtain to check.
     */
    isClosed: IsCurtainClosedFunction;
}
/**
 * Hook to interact with curtains (open or close).
 */
export declare function useCurtains(): CurtainsContextState;
/**
 * A generic callable curtain element.
 */
export type CallableCurtainElement = (...args: any) => React.ReactNode;
/**
 * A callable curtain function with typed parameters.
 */
export type CallableCurtain<F extends CallableCurtainElement> = (...args: Parameters<F>) => CurtainUuidType;
/**
 * Callable curtain function generator.
 * @param curtains The curtains context state.
 * @param curtainElement The curtain element to open when called.
 */
export declare function callableCurtain<F extends CallableCurtainElement>(curtains: CurtainsContextState, curtainElement: React.ReactNode | F): CallableCurtain<F>;
/**
 * Hook to create a simple curtain.
 * @param curtainElement Content of the curtain to open.
 */
export declare function useCallableCurtain<F extends CallableCurtainElement>(curtainElement: React.ReactNode | F): CallableCurtain<F>;
/**
 * Page curtains provider.
 */
export declare function CurtainsProvider({ children }: React.PropsWithChildren<{}>): React.JSX.Element;
